load_private_key

Function load_private_key 

pub fn load_private_key(
    priv_key_path: &PathBuf,
) -> Result<(Option<UnencryptedKeyPair>, Option<EncryptedKeyPair>)>
Load a moshpit key pair from the provided private key path.

Errors

If the private key cannot be read or is invalid, an error is returned.