validate_identity_key_pair

Function validate_identity_key_pair 

pub fn validate_identity_key_pair(
    key_alg: &str,
    public_key: &[u8],
    private_key: &[u8],
) -> Result<()>
Validate decrypted identity key material against the public key stored in the key file.

Errors

If the key algorithm is unsupported or the public/private halves do not match.