ConnectionWriter

Struct ConnectionWriter 

pub struct ConnectionWriter { /* private fields */ }
A writer over a WriteHalf and BytesMut buffer.

Implementations

Source

impl ConnectionWriter

pub fn builder() -> ConnectionWriterBuilder

Create an instance of ConnectionWriter using the builder syntax

Source

impl ConnectionWriter

pub async fn write_frame(&mut self, frame: &Frame) -> Result<()>

Write a single Frame value to the underlying stream.

The Frame value is written to the socket using the various write_* functions provided by AsyncWrite. Calling these functions directly on a TcpStream is not advised, as this will result in a large number of syscalls. However, it is fine to call these functions on a buffered write stream. The data will be written to the buffer. Once the buffer is full, it is flushed to the underlying socket.

Errors
  • I/O error.
  • Encoding error.
pub async fn write_bytes(&mut self, bytes: &[u8]) -> Result<()>

Write raw bytes to the underlying stream.

Errors
  • I/O error.