pub trait PathDefaults {
// Required methods
fn env_prefix(&self) -> String;
fn config_absolute_path(&self) -> Option<String>;
fn default_file_path(&self) -> String;
fn default_file_name(&self) -> String;
fn tracing_absolute_path(&self) -> Option<String>;
fn default_tracing_path(&self) -> String;
fn default_tracing_file_name(&self) -> String;
}Expand description
Trait to allow default paths to be supplied to load
Required Methods
Sourcefn env_prefix(&self) -> String
fn env_prefix(&self) -> String
Environment variable prefix
Sourcefn config_absolute_path(&self) -> Option<String>
fn config_absolute_path(&self) -> Option<String>
The absolute path to use for the config file
Sourcefn default_file_path(&self) -> String
fn default_file_path(&self) -> String
The default file path to use
Sourcefn default_file_name(&self) -> String
fn default_file_name(&self) -> String
The default file name to use
Sourcefn tracing_absolute_path(&self) -> Option<String>
fn tracing_absolute_path(&self) -> Option<String>
The abolute path to use for tracing output
Sourcefn default_tracing_path(&self) -> String
fn default_tracing_path(&self) -> String
The default logging path to use
Sourcefn default_tracing_file_name(&self) -> String
fn default_tracing_file_name(&self) -> String
The default log file name to use